@@ -39,3 +39,6 @@ def addon_logger():
                         )
     logger = logging.getLogger(__name__)
     return logger
+
+def main():
+    pass
\ No newline at end of file
